@@ -500,6 +500,9 @@ fn main() {
     let time = unsafe { libc::time(std::ptr::null_mut()) };
     let mut tm = std::mem::MaybeUninit::<libc::tm>::uninit();
     unsafe {
+        #[cfg(target_os = "windows")]
+        libc::localtime_s(tm.as_mut_ptr(), &time as *const _);
+        #[cfg(not(target_os = "windows"))]
         libc::localtime_r(&time as *const _, tm.as_mut_ptr());
     }
     let mut tm = unsafe { tm.assume_init() };
@@ -659,14 +662,14 @@ fn main() {
         y_offset: hands::FACE_OFFSET_Y,
     };
 
-    const SECOND_HAND_WIDTH: i64 = 23;
-    const SECOND_HAND_HEIGHT: i64 = 1;
+    const SECOND_HAND_WIDTH: i64 = 19;
+    const SECOND_HAND_HEIGHT: i64 = 0;
 
-    const MINUTE_HAND_WIDTH: i64 = 22;
+    const MINUTE_HAND_WIDTH: i64 = 20;
     const MINUTE_HAND_HEIGHT: i64 = 3;
 
     const HOUR_HAND_WIDTH: i64 = 16;
-    const HOUR_HAND_HEIGHT: i64 = 2;
+    const HOUR_HAND_HEIGHT: i64 = 3;
 
     let mut i: usize = 0;
     let mut prev_i = i;
@@ -685,14 +688,6 @@ fn main() {
         offset_min,
     );
     let mut passed_seconds = tm.tm_sec as _;
-    hands::draw_second(
-        &mut hour_hand,
-        HOUR_HAND_WIDTH,
-        HOUR_HAND_HEIGHT,
-        -5,
-        0.5 * (((hour as usize % 12) * 60 + (minutes as usize)) as f64) / 360.,
-    );
-    hour_hand.draw(&mut buffer, BLACK, None);
     hands::draw_second(
         &mut second_hand,
         SECOND_HAND_WIDTH,
@@ -701,7 +696,15 @@ fn main() {
         (passed_seconds as f64) / 60.0,
     );
     second_hand.draw(&mut buffer, BLACK, None);
-    hands::draw_second(
+    hands::draw_hand(
+        &mut hour_hand,
+        HOUR_HAND_WIDTH,
+        HOUR_HAND_HEIGHT,
+        -5,
+        0.5 * (((hour as usize % 12) * 60 + (minutes as usize)) as f64) / 360.,
+    );
+    hour_hand.draw(&mut buffer, BLACK, None);
+    hands::draw_hand(
         &mut minute_hand,
         MINUTE_HAND_WIDTH,
         MINUTE_HAND_HEIGHT,
@@ -766,6 +769,9 @@ fn main() {
                 if show_date && hour <= 2 {
                     unsafe {
                         let time = libc::time(std::ptr::null_mut());
+                        #[cfg(target_os = "windows")]
+                        libc::localtime_s(&mut tm as *mut _, &time as *const _);
+                        #[cfg(not(target_os = "windows"))]
                         libc::localtime_r(&time as *const _, &mut tm as *mut _);
                     }
                     date = date::make_date(tm.tm_mday as i64);
@@ -773,7 +779,7 @@ fn main() {
             }
             minute_hand.draw(&mut buffer, WHITE, None);
             minute_hand.clear();
-            hands::draw_second(
+            hands::draw_hand(
                 &mut minute_hand,
                 MINUTE_HAND_WIDTH,
                 MINUTE_HAND_HEIGHT,
@@ -785,10 +791,11 @@ fn main() {
         //blank_face.draw(&mut buffer, WHITE, Some(WHITE));
         hour_hand.draw(&mut buffer, WHITE, None);
         hour_hand.clear();
+        hour_hand.draw(&mut buffer, BLACK, None);
         if show_date {
             date.draw(&mut buffer, BLACK, None);
         }
-        hands::draw_second(
+        hands::draw_hand(
             &mut hour_hand,
             HOUR_HAND_WIDTH,
             HOUR_HAND_HEIGHT,
